"""
Defines typedict to translate c types to numpy types

"""


typedict = {
    'float': 'f4',
    'double': 'f8',
    'char': 'i1',
    'short': 'i2',
    'long': 'i4',
    'long long': 'i8',
    'unsigned char': 'u1',
    'unsigned short': 'u2',
    'unsigned long': 'u4',
    'unsigned long long': 'u8',
    'float32_t': 'f4',
    'float64_t': 'f8',
    'int8_t': 'i1',
    'int16_t': 'i2',
    'int32_t': 'i4',
    'int64_t': 'i8',
    'uint8_t': 'u1',
    'uint16_t': 'u2',
    'uint32_t': 'u4',
    'uint64_t': 'u8',
    'long32': 'i4',
    'ulong32': 'u4',
    'int': 'i4',
    'unsigned int': 'u4',
}
